****
* Andrew B. Hall
* Replication code for Partisan Effects of Legislative Term Limits
* Date: 12/6/13
****

use Hall_Term_Limits_Replication, clear


*** Table 2

xi: areg log_amount limit dem dem_limit i.year, a(state) cluster(state)
xi: areg log_amount limit dem dem_limit ban public i.year, a(state) cluster(state)

  
*** Figure 1

preserve

keep year state lower dem amount limit limit_mean

drop if mod(year, 2) != 0

replace amount = amount / 1000


reshape wide amount, i(year state lower) j(dem)

gen diff = amount1-amount0

sort state year lower

by state: gen treated = limit_mean > 0

by state: gen first_year = year if limit[_n] == 1 & limit[_n-1] == 0 & treated == 1
by state: egen treat_year = max(first_year) if treated == 1
gen tick_year = year - treat_year + 2

sort year
by year: egen control_outcome_tmp = mean(diff) if treated == 0
by year: egen control_outcome = max(control_outcome_tmp)
drop control_outcome_tmp

sort tick_year
by tick_year: egen treat_outcome_tmp = mean(diff) if treated == 1
by tick_year: egen treat_outcome = max(treat_outcome_tmp)
by tick_year: egen control_tick_outcome = mean(control_outcome)

drop first_year treat_year


graph twoway line control_tick_outcome treat_outcome tick_year ///
if tick_year > -11 & tick_year < 11 ///
, xlabel(-10(5)10) plotr(style(outline)) graphregion(color(white)) plotregion(color(white)) ///
legend(off) ylabel(,nogrid angle(horizontal)) graphr(c(gs16)) xtitle("Years Until Term Limit Implemented") ///
ytitle("Partisan Differential (Dem - Rep), $1000") xline(0, lcolor(black) lpattern(solid)) ///
lpattern(dash solid) lwidth(thick thick) title("Term Limits and Partisan Interest Group" "Campaign Donations")

restore
  
*** Table 3

use pres, clear


gen limit = 1 if state == "ME" & year >= 1996
replace limit = 1 if state == "CA" & year >= 1996 
replace limit = 1 if state == "CO" & year >= 1998
replace limit = 1 if state == "AR" & year >= 1998
replace limit = 1 if state == "MI" & year >= 1998
replace limit = 1 if state == "FL" & year >= 2000
replace limit = 1 if state == "OH" & year >= 2000
replace limit = 1 if state == "SD" & year >= 2000
replace limit = 1 if state == "MT" & year >= 2000
replace limit = 1 if state == "AZ" & year >= 2000
replace limit = 1 if state == "MO" & year >= 2002
replace limit = 1 if state == "OK" & year >= 2004
replace limit = 1 if state == "NE" & year >= 2006
replace limit = 1 if state == "NV" & year >= 2010
replace limit = 0 if limit != 1

 drop if state == "DC"

egen state_clust = group(state)
xtset state_clust

reg usp_ limit, cluster(state_clust)
xtreg usp_ limit, fe cluster(state_clust)
xi: xtreg usp_ limit i.year, fe cluster(state_clust)


*** Table 4

use seniority_lsq, clear

xi: areg sen dem limit dem_lim i.year, a(state) cluster(state)

xi: areg sen dem limit dem_lim ban public i.year, a(state) cluster(state)

*** Figure 2

sort state year
by state: egen term_test = mean(limit)
gen term_limited = term_test > 0
drop term_test

keep if term_limited & !limit
sort sen dem
by sen dem: gen num_sen = _N
collapse (first) num_sen, by(sen dem)
gen dem_sen = num_sen if dem == 1
sort sen
by sen: egen dem_sen_tot = max(dem_sen)
gen rep_sen = num_sen if dem == 0
sort sen
by sen: egen rep_sen_tot = max(rep_sen)
gen dem_ratio2 = dem_sen_tot / rep_sen_tot
collapse (first) dem_ratio, by(sen)
drop if sen > 10

*** Actual plot made in R
*** R code available from author upon request
save sen_for_r, replace

*** Figure 3

use Hall_Term_Limits_Replication, clear


bys state: egen mean_lim = mean(limit)
gen control = mean_lim == 0
gen treated = mean_lim > 0

drop if mean_lim == 1

egen treat_num = group(state) if treated == 1

preserve
keep if treated == 1
collapse (first) treat_num squire squire_rank, by(state)
sort treat_num
save prof_merge, replace
restore

matrix B = J(9, 2, .)
forvalues j=1/9 {
	xi: areg log_amount limit dem dem_lim i.year if control==1 | treat_num == `j', cluster(state) a(state)
	matrix B[`j', 1] = _b[dem_lim]
	matrix B[`j', 2] = `j'
}

svmat B
keep B*
rename B1 beta
rename B2 treat_num
sort treat_num

merge treat_num using prof_merge

keep if _merge == 3
drop _merge

graph twoway (scatter beta squire_rank, mlabel(state) m(i) mlabsize(large) xlabel(0(15)55)) ///
(lfit beta squire_rank, lcolor(black)), ///
plotr(style(outline)) graphregion(color(white)) plotregion(color(white)) ///
legend(off) ylabel(,nogrid) graphr(c(gs16)) xtitle("Professionalism") ytitle("Partisan Differential") ///
title("Effect of Term Limits by Professionalism")


  
*** Table 5 in Appendix
use Hall_Term_Limits_Replication, clear


xi: areg log_amount_ideo limit dem dem_limit i.year, a(state) cluster(state)
xi: areg log_amount limit dem dem_limit ban public i.year, a(state) cluster(state)


*** Table 6 in Appendix

use Hall_Term_Limits_Replication, clear

egen state_num = group(state)
sum state_num
forvalues j=1/`r(max)' {
	gen state_dummy`j' = state_num==`j'
	gen state_trend`j' = state_dummy`j'*year
}

xi: reg log_amount limit dem dem_limit i.year state_dummy* state_trend* year, cluster(state)
xi: reg log_amount limit dem dem_limit ban public i.year state_dummy* state_trend* year, cluster(state)


*** Table 7 in Appendix

use vote_analysis, clear

xi: areg dem_share limit i.year, a(state) cluster(state)


use share_analysis, clear

areg dem_frac limit i.year if lower==1, a(state) cluster(state)
areg dem_frac limit i.year if lower==0, a(state) cluster(state)


